"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { useAuth } from "@/contexts/auth-context"
import type { Store, GroceryItem } from "@/types"
import StoreManager from "@/components/store-manager"
import GroceryList from "@/components/grocery-list"
import { Card, CardContent } from "@/components/ui/card"
import { Loader2, ShoppingCart, Settings, User, LogOut } from "lucide-react"
// Import Firebase functions
import {
    fetchStores,
    fetchItems,
    addStore as fbAddStore,
    deleteStore as fbDeleteStore,
    addItem as fbAddItem,
    updateItem as fbUpdateItem,
    deleteItem as fbDeleteItem,
} from "@/lib/firebase/db"
import { useToast } from "@/hooks/use-toast"
import { useLanguage } from "@/contexts/language-context"
import { motion } from "framer-motion"
import { Button } from "@/components/ui/button"
import {
    DropdownMenu,
    DropdownMenuContent,
    DropdownMenuItem,
    DropdownMenuLabel,
    DropdownMenuSeparator,
    DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu"
import { auth } from "@/lib/firebase/config"

export default function Dashboard() {
    const { user, loading } = useAuth()
    const router = useRouter()
    const { toast } = useToast()
    const { t } = useLanguage()

    const [stores, setStores] = useState<Store[]>([])
    const [items, setItems] = useState<GroceryItem[]>([])
    const [selectedStoreId, setSelectedStoreId] = useState<string | null>(null)
    const [isLoading, setIsLoading] = useState(true)

    useEffect(() => {
        if (!loading && !user) {
            router.push("/auth")
        }
    }, [loading, user, router])

    // Load data from Firebase when component mounts
    useEffect(() => {
        const loadData = async () => {
            if (!user) return

            setIsLoading(true)
            try {
                // Fetch stores and items from Firebase
                const storesData = await fetchStores(user.uid)
                setStores(storesData)

                if (storesData.length > 0 && !selectedStoreId) {
                    setSelectedStoreId(storesData[0].id)
                }

                const itemsData = await fetchItems(user.uid)
                setItems(itemsData)
            } catch (error) {
                console.error("Error loading data:", error)
                toast({
                    variant: "destructive",
                    title: "Failed to load data",
                    description: "Please try refreshing the page.",
                })
            } finally {
                setIsLoading(false)
            }
        }

        if (user) {
            loadData()
        }
    }, [user, toast, selectedStoreId])

    const addStore = async (name: string) => {
        if (!name.trim() || !user) return

        try {
            const newStoreData = { name: name.trim(), userId: user.uid }
            const docRef = await fbAddStore(newStoreData)
            const newStore: Store = { id: docRef.id, ...newStoreData }

            setStores([...stores, newStore])
            setSelectedStoreId(newStore.id)
        } catch (error) {
            console.error("Error adding store:", error)
            toast({
                variant: "destructive",
                title: "Failed to add store",
                description: "Please try again.",
            })
        }
    }

    const deleteStore = async (id: string) => {
        if (!user) return

        try {
            await fbDeleteStore(id)

            // Delete all associated items
            const itemsToDelete = items.filter((item) => item.storeId === id)
            for (const item of itemsToDelete) {
                await fbDeleteItem(item.id)
            }

            const updatedStores = stores.filter((store) => store.id !== id)
            const updatedItems = items.filter((item) => item.storeId !== id)

            setStores(updatedStores)
            setItems(updatedItems)

            if (selectedStoreId === id) {
                setSelectedStoreId(updatedStores.length > 0 ? updatedStores[0].id : null)
            }
        } catch (error) {
            console.error("Error deleting store:", error)
            toast({
                variant: "destructive",
                title: "Failed to delete store",
                description: "Please try again.",
            })
        }
    }

    const addItem = async (name: string, quantity: number, buyOnSaleOnly: boolean) => {
        if (!name.trim() || !selectedStoreId || quantity <= 0 || !user) return

        try {
            const newItemData = {
                name: name.trim(),
                quantity,
                storeId: selectedStoreId,
                purchased: false,
                buyOnSaleOnly: buyOnSaleOnly,
                userId: user.uid,
            }

            const docRef = await fbAddItem(newItemData)
            const newItem: GroceryItem = { id: docRef.id, ...newItemData }

            setItems([...items, newItem])
        } catch (error) {
            console.error("Error adding item:", error)
            toast({
                variant: "destructive",
                title: "Failed to add item",
                description: "Please try again.",
            })
        }
    }

    const toggleItemPurchased = async (id: string) => {
        try {
            const item = items.find((item) => item.id === id)
            if (!item) return

            const newPurchasedState = !item.purchased
            await fbUpdateItem(id, { purchased: newPurchasedState })

            setItems(items.map((item) => (item.id === id ? { ...item, purchased: newPurchasedState } : item)))
        } catch (error) {
            console.error("Error updating item:", error)
            toast({
                variant: "destructive",
                title: "Failed to update item",
                description: "Please try again.",
            })
        }
    }

    const toggleItemSaleOnly = async (id: string) => {
        try {
            const item = items.find((item) => item.id === id)
            if (!item) return

            const newSaleOnlyState = !item.buyOnSaleOnly
            await fbUpdateItem(id, { buyOnSaleOnly: newSaleOnlyState })

            setItems(items.map((item) => (item.id === id ? { ...item, buyOnSaleOnly: newSaleOnlyState } : item)))
        } catch (error) {
            console.error("Error updating item:", error)
            toast({
                variant: "destructive",
                title: "Failed to update item",
                description: "Please try again.",
            })
        }
    }

    const deleteItem = async (id: string) => {
        try {
            await fbDeleteItem(id)
            setItems(items.filter((item) => item.id !== id))
        } catch (error) {
            console.error("Error deleting item:", error)
            toast({
                variant: "destructive",
                title: "Failed to delete item",
                description: "Please try again.",
            })
        }
    }

    const updateItemQuantity = async (id: string, change: number) => {
        try {
            const item = items.find((item) => item.id === id)
            if (!item) return

            const newQuantity = Math.max(1, item.quantity + change)
            await fbUpdateItem(id, { quantity: newQuantity })

            setItems(items.map((item) => (item.id === id ? { ...item, quantity: newQuantity } : item)))
        } catch (error) {
            console.error("Error updating item quantity:", error)
            toast({
                variant: "destructive",
                title: "Failed to update quantity",
                description: "Please try again.",
            })
        }
    }

    const handleSignOut = async () => {
        try {
            await auth.signOut()
            router.push("/auth")
        } catch (error) {
            console.error("Error signing out:", error)
            toast({
                variant: "destructive",
                title: "Failed to sign out",
                description: "Please try again.",
            })
        }
    }

    const filteredItems = items.filter((item) => item.storeId === selectedStoreId)
    const selectedStore = stores.find((store) => store.id === selectedStoreId)

    if (loading || isLoading) {
        return (
            <div className="flex justify-center items-center min-h-[calc(100vh-4rem)]">
                <Loader2 className="h-12 w-12 animate-spin text-emerald-500" />
            </div>
        )
    }

    if (!user) return null

    return (
        <div className="min-h-screen bg-gradient-to-b from-slate-50 to-slate-100 dark:from-slate-900 dark:to-slate-800">
            <div className="container mx-auto p-4 md:p-6 lg:p-8">
                <div className="grid grid-cols-1 gap-6 lg:grid-cols-3">
                    {/* Store Management Column */}
                    <motion.div
                        initial={{ opacity: 0, y: 20 }}
                        animate={{ opacity: 1, y: 0 }}
                        transition={{ duration: 0.5 }}
                        className="lg:col-span-1 order-2 lg:order-1"
                    >
                        <StoreManager
                            stores={stores}
                            addStore={addStore}
                            deleteStore={deleteStore}
                            selectedStoreId={selectedStoreId}
                            setSelectedStoreId={setSelectedStoreId}
                        />
                    </motion.div>

                    {/* Grocery List Column */}
                    <motion.div
                        initial={{ opacity: 0, y: 20 }}
                        animate={{ opacity: 1, y: 0 }}
                        transition={{ duration: 0.5, delay: 0.2 }}
                        className="lg:col-span-2 order-1 lg:order-2"
                    >
                        {selectedStore ? (
                            <GroceryList
                                store={selectedStore}
                                items={filteredItems}
                                addItem={addItem}
                                toggleItemPurchased={toggleItemPurchased}
                                toggleItemSaleOnly={toggleItemSaleOnly}
                                deleteItem={deleteItem}
                                updateItemQuantity={updateItemQuantity}
                            />
                        ) : stores.length > 0 ? (
                            <Card className="shadow-lg border-0 bg-white dark:bg-slate-900 overflow-hidden">
                                <CardContent className="p-12 text-center">
                                    <div className="w-16 h-16 rounded-full bg-emerald-100 dark:bg-emerald-900/30 flex items-center justify-center mx-auto mb-4">
                                        <ShoppingCart className="h-8 w-8 text-emerald-500 dark:text-emerald-400" />
                                    </div>
                                    <h3 className="text-lg font-medium text-slate-800 dark:text-white mb-2">
                                        {t("selectStore") || "Select a Store"}
                                    </h3>
                                    <p className="text-slate-500 dark:text-slate-400 mb-6">
                                        {t("selectStoreDescription") || "Please select a store from the list to view its items"}
                                    </p>
                                </CardContent>
                            </Card>
                        ) : (
                            <Card className="shadow-lg border-0 bg-white dark:bg-slate-900 overflow-hidden">
                                <CardContent className="p-12 text-center">
                                    <div className="w-16 h-16 rounded-full bg-emerald-100 dark:bg-emerald-900/30 flex items-center justify-center mx-auto mb-4">
                                        <ShoppingCart className="h-8 w-8 text-emerald-500 dark:text-emerald-400" />
                                    </div>
                                    <h3 className="text-lg font-medium text-slate-800 dark:text-white mb-2">
                                        {t("noStores") || "No Stores Yet"}
                                    </h3>
                                    <p className="text-slate-500 dark:text-slate-400 mb-6">
                                        {t("addStoreFirst") || "Add your first store to get started with your shopping list"}
                                    </p>
                                </CardContent>
                            </Card>
                        )}
                    </motion.div>
                </div>
            </div>
        </div>
    )
}
